@@ -1,22 +1,46 @@
-set comb_ul_ip         0
+################################################################################################
+# Copyright (c) 2006-2009 Trevor Williams                                                      #
+#                                                                                              #
+# This program is free software; you can redistribute it and/or modify                         #
+# it under the terms of the GNU General Public License as published by the Free Software       #
+# Foundation; either version 2 of the License, or (at your option) any later version.          #
+#                                                                                              #
+# This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;    #
+# without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.    #
+# See the GNU General Public License for more details.                                         #
+#                                                                                              #
+# You should have received a copy of the GNU General Public License along with this program;   #
+# if not, write to the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. #
+################################################################################################
+
+set comb_ul_inc_ip     0
+set comb_ul_exc_ip     0
 set comb_curr_uline_id 0
 set comb_curr_exp_id   0
 set comb_bheight       -1
 set curr_comb_ptr      "" 
+set comb_geometry      ""
+set comb_gui_saved     0
 
 proc K {x y} {
   set x
 }
 
-proc comb_calc_indexes {uline line first} {
+proc comb_calc_indices {uline line first} {
 
-  global comb_uline_indexes comb_ul_ip
+  global comb_uline_indices comb_uline_exc_indices comb_ul_inc_ip comb_ul_exc_ip
+  global comb_exp_excludes
 
-  set i 0
+  set i                      0
+  set comb_uline_indices     ""
+  set comb_uline_exc_indices ""
 
-  if {[expr $first == 0] && [expr $comb_ul_ip == 1]} {
-    set i          [string first "-" $uline 0]
-    set comb_ul_ip 0
+  if {$first == 0 && $comb_ul_inc_ip == 1} {
+    set i              [string first "-" $uline 0]
+    set comb_ul_inc_ip 0
+  } elseif {$first == 0 && $comb_ul_exc_ip == 1} {
+    set i              [string first "-" $uline 0]
+    set comb_ul_exc_ip 0
   } else {
     set i [string first "|" $uline 0]
   }
@@ -24,22 +48,43 @@ proc comb_calc_indexes {uline line first} {
   while {$i != -1} {
     if {$first == 1} {
       set first              0
-      set comb_uline_indexes "$line.$i"
-      set comb_ul_ip         1
-    } else {
-      if {$comb_ul_ip == 1} {
-        lappend comb_uline_indexes "$line.[expr $i + 1]"
-        set comb_ul_ip 0
+      set id [regexp -inline -start $i -- {\d+} $uline]
+      if {[lindex $comb_exp_excludes $id] == 1} {
+        set comb_uline_exc_indices $line.$i
+        set comb_ul_exc_ip         1
       } else {
-        lappend comb_uline_indexes "$line.$i"
-        set comb_ul_ip 1
+        set comb_ul_inc_ip         1
+      }
+      set comb_uline_indices "$line.$i"
+    } else {
+      if {$comb_ul_inc_ip == 1} {
+        lappend comb_uline_indices "$line.[expr $i + 1]"
+        set comb_ul_inc_ip 0
+      } elseif {$comb_ul_exc_ip == 1} {
+        lappend comb_uline_indices     "$line.[expr $i + 1]"
+        lappend comb_uline_exc_indices "$line.[expr $i + 1]"
+        set comb_ul_exc_ip 0
+      } else {
+        set id [regexp -inline -start $i -- {\d+} $uline]
+        if {[lindex $comb_exp_excludes $id] == 1} {
+          lappend comb_uline_exc_indices "$line.$i"
+          set comb_ul_exc_ip 1
+        } else {
+          set comb_ul_inc_ip 1
+        }
+        lappend comb_uline_indices "$line.$i"
       }
     }
     set i [string first "|" $uline [expr $i + 1]]
   }
 
-  if {[expr $i == -1] && [expr $comb_ul_ip == 1]} {
-    lappend comb_uline_indexes "$line.end"
+  if {$i == -1} {
+    if {$comb_ul_inc_ip == 1} {
+      lappend comb_uline_indices "$line.end"
+    } elseif {$comb_ul_exc_ip == 1} {
+      lappend comb_uline_exc_indices "$line.end"
+      lappend comb_uline_indices "$line.end"
+    }
   }
     
 }
@@ -47,24 +92,27 @@ proc comb_calc_indexes {uline line first} {
 proc display_comb_info {} {
 
   global comb_code comb_uline_groups comb_ulines
-  global comb_uline_indexes comb_first_uline
+  global comb_uline_indices comb_uline_exc_indices comb_first_uline
   global comb_gen_ulines comb_curr_uline_id
   global comb_curr_cursor comb_curr_info
-  global uncov_fgColor
+  global uncov_fgColor uncov_bgColor
+  global cov_fgColor cov_bgColor
 
   set curr_uline 0
 
   # Remove any tags associated with the toggle text box
-  .combwin.f.top.t tag delete comb_enter
-  .combwin.f.top.t tag delete comb_leave
-  .combwin.f.top.t tag delete comb_bp1
-  .combwin.f.top.t tag delete comb_bp3
+  .combwin.pw.top.t tag delete comb_enter
+  .combwin.pw.top.t tag delete comb_leave
+  .combwin.pw.top.t tag delete comb_bp1
+  .combwin.pw.top.t tag delete comb_bp3
+  .combwin.pw.top.t tag delete comb_inc_hl
+  .combwin.pw.top.t tag delete comb_exc_hl
 
   # Allow us to clear out textbox and repopulate
-  .combwin.f.top.t configure -state normal
+  .combwin.pw.top.t configure -state normal
 
   # Clear the textbox before any insertion is being made
-  .combwin.f.top.t delete 1.0 end
+  .combwin.pw.top.t delete 1.0 end
 
   # Get length of comb_code list
   set code_len [llength $comb_code]
@@ -76,89 +124,105 @@ proc display_comb_info {} {
   set curr_line 1
   set first     1
   for {set j 0} {$j<$code_len} {incr j} {
-    .combwin.f.top.t insert end "[lindex $comb_code $j]\n"
+    .combwin.pw.top.t insert end "[lindex $comb_code $j]\n"
     incr curr_line
-    .combwin.f.top.t insert end "[lindex $comb_gen_ulines $j]\n"
-    comb_calc_indexes [lindex $comb_gen_ulines $j] $curr_line $first
+    .combwin.pw.top.t insert end "[lindex $comb_gen_ulines $j]\n"
+    comb_calc_indices [lindex $comb_gen_ulines $j] $curr_line $first
     incr curr_line
     set first 0
-    .combwin.f.top.t insert end "\n"
+    .combwin.pw.top.t insert end "\n"
     incr curr_line
   }
 
-  # Keep user from writing in text box
-  .combwin.f.top.t configure -state disabled
+  # Perform syntax highlighting
+  verilog_highlight .combwin.pw.top.t
 
-  # Add expression tags and bindings
-  if {[llength $comb_uline_indexes] > 0} {
-    eval ".combwin.f.top.t tag add comb_enter $comb_uline_indexes"
-    eval ".combwin.f.top.t tag add comb_leave $comb_uline_indexes"
-    eval ".combwin.f.top.t tag add comb_bp1 $comb_uline_indexes"
-    eval ".combwin.f.top.t tag add comb_bp3 $comb_uline_indexes"
-    .combwin.f.top.t tag configure comb_bp1 -foreground $uncov_fgColor
-    .combwin.f.top.t tag bind comb_enter <Enter> {
-      set comb_curr_cursor [.combwin.f.top.t cget -cursor]
-      .combwin.f.top.t configure -cursor hand2
+  # Keep user from writing in text box
+  .combwin.pw.top.t configure -state disabled
+
+  # Add included expression tags and bindings
+  if {[llength $comb_uline_indices] > 0} {
+    eval ".combwin.pw.top.t tag add comb_enter $comb_uline_indices"
+    eval ".combwin.pw.top.t tag add comb_leave $comb_uline_indices"
+    eval ".combwin.pw.top.t tag add comb_bp1 $comb_uline_indices"
+    eval ".combwin.pw.top.t tag add comb_bp3 $comb_uline_indices"
+    eval ".combwin.pw.top.t tag add comb_inc_hl $comb_uline_indices"
+    .combwin.pw.top.t tag configure comb_inc_hl -foreground $uncov_fgColor -background $uncov_bgColor
+    .combwin.pw.top.t tag bind comb_enter <Enter> {
+      set comb_curr_cursor [.combwin.pw.top.t cget -cursor]
+      .combwin.pw.top.t configure -cursor hand2
       .combwin.info configure -text "Click left button for coverage info / Click right button to see parent expression"
     }
-    .combwin.f.top.t tag bind comb_leave <Leave> {
-      .combwin.f.top.t configure -cursor $comb_curr_cursor
+    .combwin.pw.top.t tag bind comb_leave <Leave> {
+      .combwin.pw.top.t configure -cursor $comb_curr_cursor
       .combwin.info configure -text $comb_curr_info
     }
-    .combwin.f.top.t tag bind comb_bp1 <ButtonPress-1> {
-      set selected_range [.combwin.f.top.t tag prevrange comb_bp1 {current + 1 chars}]
+    .combwin.pw.top.t tag bind comb_bp1 <ButtonPress-1> {
+      set selected_range [.combwin.pw.top.t tag prevrange comb_bp1 {current + 1 chars}]
       set redraw [move_display_down [get_expr_index_from_range $selected_range 1]]
       if {$redraw == 1} {
-        set text_x [.combwin.f.top.t xview]
-        set text_y [.combwin.f.top.t yview]
+        set text_x [.combwin.pw.top.t xview]
+        set text_y [.combwin.pw.top.t yview]
         display_comb_info
-        .combwin.f.top.t xview moveto [lindex $text_x 0]
-        .combwin.f.top.t yview moveto [lindex $text_y 0]
+        .combwin.pw.top.t xview moveto [lindex $text_x 0]
+        .combwin.pw.top.t yview moveto [lindex $text_y 0]
       } 
     }
-    .combwin.f.top.t tag bind comb_bp3 <ButtonPress-3> {
-      set selected_range [.combwin.f.top.t tag prevrange comb_bp3 {current + 1 chars}]
+    .combwin.pw.top.t tag bind comb_bp3 <ButtonPress-3> {
+      set selected_range [.combwin.pw.top.t tag prevrange comb_bp3 {current + 1 chars}]
       set redraw [move_display_up [get_expr_index_from_range $selected_range 0]]
       if {$redraw == 1} {
-        set text_x [.combwin.f.top.t xview]
-        set text_y [.combwin.f.top.t yview]
+        set text_x [.combwin.pw.top.t xview]
+        set text_y [.combwin.pw.top.t yview]
         display_comb_info
-        .combwin.f.top.t xview moveto [lindex $text_x 0]
-        .combwin.f.top.t yview moveto [lindex $text_y 0]
+        .combwin.pw.top.t xview moveto [lindex $text_x 0]
+        .combwin.pw.top.t yview moveto [lindex $text_y 0]
       } 
     }
   }
 
+  # Add excluded expression tags and bindings
+  if {[llength $comb_uline_exc_indices] > 0} {
+    eval ".combwin.pw.top.t tag add comb_exc_hl $comb_uline_exc_indices"
+    .combwin.pw.top.t tag configure comb_exc_hl -foreground $cov_fgColor -background $cov_bgColor
+  }
+
 }
 
 proc display_comb_coverage {ulid} {
 
-  global curr_funit_name curr_funit_type comb_expr_cov comb_curr_exp_id
+  global curr_block comb_expr_cov comb_curr_exp_id
+  global comb_curr_excluded comb_exp_excludes
+  global comb_curr_reason comb_exp_reasons
 
   # Allow us to clear out text box and repopulate
-  .combwin.f.bot.t configure -state normal
+  .combwin.pw.bot.t configure -state normal
 
   # Clear the text-box before any insertion is being made
-  .combwin.f.bot.t delete 1.0 end
+  .combwin.pw.bot.t delete 1.0 end
 
   # Get combinational coverage information
-  set comb_expr_cov ""
-  tcl_func_get_comb_coverage $curr_funit_name $curr_funit_type $comb_curr_exp_id $ulid
+  set comb_expr_cov [tcl_func_get_comb_coverage $curr_block $comb_curr_exp_id $ulid]
 
   # Display coverage information
-  .combwin.f.bot.t insert end "\n\n"
+  .combwin.pw.bot.t insert end "\n\n"
   foreach line $comb_expr_cov {
-    .combwin.f.bot.t insert end "$line\n"
+    .combwin.pw.bot.t insert end "$line\n"
   }
 
-  .combwin.f.bot.t configure -state disabled
+  .combwin.pw.bot.t configure -state disabled
+
+  # Set excluded checkbutton correctly
+  .combwin.pw.bot.e configure -state normal
+  set comb_curr_excluded [lindex $comb_exp_excludes $ulid]
+  set comb_curr_reason   [lindex $comb_exp_reasons $ulid]
 
 }
 
 proc get_expr_index_from_range {selected_range get_uline_id} {
 
   global comb_uline_expr comb_curr_uline_id
-  global curr_funit_name curr_funit_type
+  global curr_block
 
   # Get range information
   set line       [lindex [split [lindex $selected_range 0] .] 0]
@@ -166,7 +230,7 @@ proc get_expr_index_from_range {selected_range get_uline_id} {
   set end_char   [expr [lindex [split [lindex $selected_range 1] .] 1] - 1]
 
   # Get ID from string
-  set id [regexp -inline -- {\d+} [.combwin.f.top.t get [lindex $selected_range 0] [lindex $selected_range 1]]]
+  set id [regexp -inline -- {\d+} [.combwin.pw.top.t get [lindex $selected_range 0] [lindex $selected_range 1]]]
 
   if {$id != -1} {
 
@@ -343,7 +407,8 @@ proc organize_underlines {} {
     for {set j [expr [lindex $comb_uline_groups $i] - 1]} {$j >= 0} {incr j -1} {
       set curr_uline [lindex $comb_ulines [comb_calc_line_index $i $j]]
       set vbar [string first "|" $curr_uline 0]
-      set hbar [string first "-" $curr_uline 0]
+      regexp -indices -- {([0-9]|-)} $curr_uline m
+      set hbar [lindex $m 0]
       if {[expr $vbar < $hbar] && [expr $vbar != -1]} {
         set curr_char $vbar
       } else {
@@ -460,11 +525,11 @@ proc display_comb {curr_index} {
   global uncovered_combs start_line
 
   # Calculate expression ID and line number
-  set all_ranges [.bot.right.txt tag ranges uncov_highlight]
-  set my_range   [.bot.right.txt tag prevrange uncov_highlight "$curr_index + 1 chars"]
-  set index [expr [lsearch -exact $all_ranges [lindex $my_range 0]] / 2]
-  set expr_id [lindex [lindex $uncovered_combs $index] 2]
-  set sline [expr [lindex [split [lindex $my_range 0] "."] 0] + $start_line - 1]
+  set all_ranges [.bot.right.txt tag ranges uncov_button]
+  set my_range   [.bot.right.txt tag prevrange uncov_button "$curr_index + 1 chars"]
+  set index      [expr [lsearch -exact $all_ranges [lindex $my_range 0]] / 2]
+  set expr_id    [lindex [lindex $uncovered_combs $index] 2]
+  set sline      [expr [lindex [split [lindex $my_range 0] "."] 0] + $start_line - 1]
 
   # Get range of current signal
   set curr_range [.bot.right.txt tag prevrange uncov_button "$curr_index + 1 chars"]
@@ -477,10 +542,10 @@ proc display_comb {curr_index} {
   goto_uncov [lindex $my_range 0]
 
   # Get range of previous signal
-  set prev_comb_index [lindex [.bot.right.txt tag prevrange uncov_highlight [lindex $curr_index 0]] 0]
+  set prev_comb_index [lindex [.bot.right.txt tag prevrange uncov_button [lindex $curr_index 0]] 0]
 
   # Get range of next signal
-  set next_comb_index [lindex [.bot.right.txt tag nextrange uncov_highlight [lindex $curr_range 1]] 0]
+  set next_comb_index [lindex [.bot.right.txt tag nextrange uncov_button [lindex $curr_range 1]] 0]
 
   # Now create the toggle window
   create_comb_window $expr_id $sline
@@ -493,54 +558,61 @@ proc display_comb {curr_index} {
 proc create_comb_window {expr_id sline} {
 
   global comb_code comb_uline_groups comb_ulines comb_curr_exp_id
-  global curr_funit_name curr_funit_type
-  global file_name comb_curr_info
+  global curr_block
+  global comb_curr_info
   global prev_comb_index next_comb_index
-  global curr_comb_ptr
+  global curr_comb_ptr comb_curr_excluded comb_curr_reason
+  global comb_exp_excludes comb_exp_reasons HOME
+  global comb_geometry comb_gui_saved
+
+  # Clear the comb_curr_excluded global variable
+  set comb_curr_excluded 0
 
   # Now create the window and set the grab to this window
   if {[winfo exists .combwin] == 0} {
 
+    set comb_gui_saved 0
+
     # Create new window
     toplevel .combwin
     wm title .combwin "Combinational Logic Coverage - Verbose"
 
     # Create all frames for the window
-    frame .combwin.f -bg grey -width 700 -height 350
-    frame .combwin.f.top -relief raised -borderwidth 1
-    frame .combwin.f.bot -relief raised -borderwidth 1
-    frame .combwin.f.handle -borderwidth 2 -relief raised -cursor sb_v_double_arrow
-
-    # Create frame slider
-    place .combwin.f.top -relwidth 1 -height -1
-    place .combwin.f.bot -relwidth 1 -rely 1 -anchor sw -height -1
-    place .combwin.f.handle -relx 0.8 -anchor e -width 8 -height 8
-
-    bind .combwin.f <Configure> {
-      set H [winfo height .combwin.f]
-      set Y0 [winfo rooty .combwin.f]
-      if {$comb_bheight == -1} {
-        set comb_bheight [expr .4 * $H]
-      }
-      comb_place $H $comb_bheight
-    }
-
-    bind .combwin.f.handle <B1-Motion> {
-      set comb_bheight [expr $H - [expr %Y - $Y0]]
-      comb_place $H $comb_bheight
-    }
+    panedwindow .combwin.pw -bg grey -width 700 -height 350 -sashrelief raised -sashwidth 4 -orient vertical
+    frame .combwin.pw.top -relief raised -borderwidth 1
+    frame .combwin.pw.bot -relief raised -borderwidth 1
 
     # Add expression information
-    label .combwin.f.top.l -anchor w -text "Expression:"
-    text  .combwin.f.top.t -height 20 -width 100 -xscrollcommand ".combwin.f.top.hb set" -yscrollcommand ".combwin.f.top.vb set" -wrap none
-    scrollbar .combwin.f.top.hb -orient horizontal -command ".combwin.f.top.t xview"
-    scrollbar .combwin.f.top.vb -orient vertical   -command ".combwin.f.top.t yview"
+    label .combwin.pw.top.l -anchor w -text "Expression:"
+    text  .combwin.pw.top.t -height 10 -width 100 -xscrollcommand ".combwin.pw.top.hb set" -yscrollcommand ".combwin.pw.top.vb set" -wrap none
+    scrollbar .combwin.pw.top.hb -orient horizontal -command ".combwin.pw.top.t xview"
+    scrollbar .combwin.pw.top.vb -orient vertical   -command ".combwin.pw.top.t yview"
 
     # Add expression coverage information
-    label .combwin.f.bot.l -anchor w -text "Coverage Information:  ('*' represents a case that was not hit)"
-    text  .combwin.f.bot.t -height 10 -width 100 -xscrollcommand ".combwin.f.bot.hb set" -yscrollcommand ".combwin.f.bot.vb set" -wrap none -state disabled
-    scrollbar .combwin.f.bot.hb -orient horizontal -command ".combwin.f.bot.t xview"
-    scrollbar .combwin.f.bot.vb -orient vertical   -command ".combwin.f.bot.t yview"
+    label .combwin.pw.bot.l -anchor w -text "Coverage Information:  ('*' represents a case that was not hit)"
+    checkbutton .combwin.pw.bot.e -anchor e -text "Excluded" -state disabled -variable comb_curr_excluded -command {
+      set comb_curr_reason ""
+      if {$exclude_reasons_enabled == 1 && $comb_curr_excluded == 1} {
+        set comb_curr_reason [get_exclude_reason .combwin]
+      }
+      tcl_func_set_comb_exclude $curr_block $comb_curr_exp_id $comb_curr_uline_id $comb_curr_excluded $comb_curr_reason
+      set comb_exp_excludes [lreplace $comb_exp_excludes $comb_curr_uline_id $comb_curr_uline_id $comb_curr_excluded]
+      set comb_exp_reasons  [lreplace $comb_exp_reasons  $comb_curr_uline_id $comb_curr_uline_id $comb_curr_reason]
+      set text_x [.bot.right.txt xview]
+      set text_y [.bot.right.txt yview]
+      process_comb_cov
+      display_comb_info  ;# Redisplay the expression
+      .bot.right.txt xview moveto [lindex $text_x 0]
+      .bot.right.txt yview moveto [lindex $text_y 0]
+      populate_listbox
+      enable_cdd_save
+      set_pointer curr_comb_ptr $curr_comb_ptr
+    }
+    set_exclude_reason_balloon .combwin.pw.bot.e {$comb_curr_excluded} {$comb_curr_reason}
+    set_balloon .combwin.pw.bot.e "If set, excludes the expression/subexpression displayed in the lower panel from coverage consideration"
+    text  .combwin.pw.bot.t -height 10 -width 100 -xscrollcommand ".combwin.pw.bot.hb set" -yscrollcommand ".combwin.pw.bot.vb set" -wrap none -state disabled
+    scrollbar .combwin.pw.bot.hb -orient horizontal -command ".combwin.pw.bot.t xview"
+    scrollbar .combwin.pw.bot.vb -orient vertical   -command ".combwin.pw.bot.t yview"
 
     # Create information bar
     label .combwin.info -anchor w -relief raised -borderwidth 1 -width 100
@@ -551,49 +623,73 @@ proc create_comb_window {expr_id sline} {
       rm_pointer curr_comb_ptr
       destroy .combwin
     }
-    button .combwin.bf.help -text "Help" -width 10 -command {
-      help_show_manual comb
-    }
-    button .combwin.bf.prev -text "<--" -command {
+    help_button .combwin.bf.help chapter.gui.logic ""
+    button .combwin.bf.prev -image [image create photo -file [file join $HOME scripts left_arrow.gif]] -relief flat -command {
       display_comb $prev_comb_index
     }
-    button .combwin.bf.next -text "-->" -command {
+    set_balloon .combwin.bf.prev "Click to view the previous uncovered expression tree in this window"
+    button .combwin.bf.next -image [image create photo -file [file join $HOME scripts right_arrow.gif]] -relief flat -command {
       display_comb $next_comb_index
     }
+    set_balloon .combwin.bf.next "Click to view the next uncovered expression tree in this window"
     
     # Pack the button widgets into button frame
-    pack .combwin.bf.prev  -side left  -padx 8 -pady 4
-    pack .combwin.bf.next  -side left  -padx 8 -pady 4
-    pack .combwin.bf.help  -side right -padx 8 -pady 4
+    pack .combwin.bf.prev  -side left
+    pack .combwin.bf.next  -side left
+    pack .combwin.bf.help  -side right -pady 4
     pack .combwin.bf.close -side right -padx 8 -pady 4
 
     # Pack the widgets into the top frame
-    grid rowconfigure    .combwin.f.top 1 -weight 1
-    grid columnconfigure .combwin.f.top 0 -weight 1
-    grid .combwin.f.top.l  -row 0 -column 0 -sticky nsew
-    grid .combwin.f.top.t  -row 1 -column 0 -sticky nsew
-    grid .combwin.f.top.hb -row 2 -column 0 -sticky ew
-    grid .combwin.f.top.vb -row 1 -column 1 -sticky ns
+    grid rowconfigure    .combwin.pw.top 1 -weight 1
+    grid columnconfigure .combwin.pw.top 0 -weight 1
+    grid .combwin.pw.top.l  -row 0 -column 0 -sticky nsew
+    grid .combwin.pw.top.t  -row 1 -column 0 -sticky nsew
+    grid .combwin.pw.top.hb -row 2 -column 0 -sticky ew
+    grid .combwin.pw.top.vb -row 1 -column 1 -sticky ns
 
     # Pack the widgets into the bottom frame
-    grid rowconfigure    .combwin.f.bot 1 -weight 1
-    grid columnconfigure .combwin.f.bot 0 -weight 1
-    grid .combwin.f.bot.l  -row 0 -column 0 -sticky nsew
-    grid .combwin.f.bot.t  -row 1 -column 0 -sticky nsew
-    grid .combwin.f.bot.hb -row 2 -column 0 -sticky ew
-    grid .combwin.f.bot.vb -row 1 -column 1 -sticky ns
+    grid rowconfigure    .combwin.pw.bot 1 -weight 1
+    grid columnconfigure .combwin.pw.bot 0 -weight 1
+    grid .combwin.pw.bot.l  -row 0 -column 0 -sticky nsew
+    grid .combwin.pw.bot.e  -row 0 -column 1 -sticky nsew
+    grid .combwin.pw.bot.t  -row 1 -column 0 -columnspan 2 -sticky nsew
+    grid .combwin.pw.bot.vb -row 1 -column 2 -sticky ns
+    grid .combwin.pw.bot.hb -row 2 -column 0 -columnspan 2 -sticky ew
+
+    # Pack the top and bottom frame of the panedwindow
+    .combwin.pw add .combwin.pw.top
+    .combwin.pw add .combwin.pw.bot
+    .combwin.pw paneconfigure .combwin.pw.top -stretch always
+    .combwin.pw paneconfigure .combwin.pw.bot -stretch never
 
     # Pack the frame, informational bar, and button frame into the window
-    pack .combwin.f    -fill both -expand yes
+    pack .combwin.pw   -fill both -expand yes
     pack .combwin.info -fill both
     pack .combwin.bf   -fill both
 
+    # If the geometry was specified for this window, use it
+    if {$comb_geometry != ""} {
+      wm geometry .combwin $comb_geometry
+    }
+
+    # Handle the closing of this window
+    wm protocol .combwin WM_DELETE_WINDOW {
+      save_comb_gui_elements 0
+      destroy .combwin
+    }
+    bind .combwin <Destroy> {
+      save_comb_gui_elements 0
+    }
+
   } else {
 
     # Clear out bottom text box
-    .combwin.f.bot.t configure -state normal
-    .combwin.f.bot.t delete 1.0 end
-    .combwin.f.bot.t configure -state disabled
+    .combwin.pw.bot.t configure -state normal
+    .combwin.pw.bot.t delete 1.0 end
+    .combwin.pw.bot.t configure -state disabled
+
+    # Reset the excluded checkbutton
+    .combwin.pw.bot.e configure -state disabled
 
   }
 
@@ -613,11 +709,13 @@ proc create_comb_window {expr_id sline} {
   set comb_code         "" 
   set comb_uline_groups "" 
   set comb_ulines       ""
+  set comb_exp_excludes ""
+  set comb_exp_reasons  ""
   set comb_curr_exp_id  $expr_id
-  tcl_func_get_comb_expression $curr_funit_name $curr_funit_type $expr_id
+  tcl_func_get_comb_expression $curr_block $expr_id
 
   # Initialize text in information bar
-  set comb_curr_info "Filename: $file_name, module: $curr_funit_name, line: $sline"
+  set comb_curr_info "Filename: [tcl_func_get_filename $curr_block], module: [tcl_func_get_funit_name $curr_block], line: $sline"
   .combwin.info configure -text $comb_curr_info
 
   organize_underlines
@@ -630,14 +728,6 @@ proc create_comb_window {expr_id sline} {
 
 }
 
-proc comb_place {height value} {
-
-  place .combwin.f.top    -height [expr $height - $value]
-  place .combwin.f.handle -y [expr $height - $value]
-  place .combwin.f.bot    -height $value
-
-}
-
 # Updates the GUI elements of the combinational logic window when some type of event causes the
 # current metric mode to change.
 proc update_comb {} {
@@ -648,7 +738,7 @@ proc update_comb {} {
   if {[winfo exists .combwin] == 1} {
 
     # If the current metric mode is not combinational logic, disable the prev/next buttons
-    if {$cov_rb != "comb"} {
+    if {$cov_rb != "Logic"} {
 
       .combwin.bf.prev configure -state disabled
       .combwin.bf.next configure -state disabled
@@ -675,3 +765,36 @@ proc update_comb {} {
   }
 
 }
+
+proc clear_comb {} {
+
+  global comb_ul_ip comb_curr_uline_id comb_curr_exp_id comb_bheight 
+  global curr_comb_ptr
+
+  # Reset the variables
+  set curr_comb_ptr      ""
+  set comb_ul_ip         0
+  set comb_curr_uline_id 0
+  set comb_curr_exp_id   0
+  set comb_bheight       -1
+
+  # Destroy the combinational logic window
+  destroy .combwin
+
+}
+
+# Saves the GUI elements from the combinational logic window setup that should be saved
+proc save_comb_gui_elements {main_exit} {
+
+  global comb_gui_saved
+  global comb_geometry comb_top_height
+
+  if {$comb_gui_saved == 0 } {
+    if {$main_exit == 0 || [winfo exists .combwin] == 1} {
+      set comb_gui_saved  1
+      set comb_geometry   [winfo geometry .combwin]
+    }
+  }
+
+}
+
