@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2006-2009 Trevor Williams
+ Copyright (c) 2006-2010 Trevor Williams
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by the Free Software
@@ -534,7 +534,7 @@ static void fsm_arg_parse_trans(
   assert( expr != NULL );
 
   /* Convert expression value to a string */
-  tmp = str = vector_to_string( expr->value, ESUPPL_STATIC_BASE( expr->suppl ), FALSE );
+  tmp = str = vector_to_string( expr->value, ESUPPL_STATIC_BASE( expr->suppl ), FALSE, 0 );
 
   Try {
 
@@ -618,7 +618,7 @@ void fsm_arg_parse_attr(
     } else if( (index == 2) && (strcmp( curr->name, "is" ) == 0) && (curr->expr != NULL) ) {
       if( fsml == NULL ) {
         int slen;
-        tmp = str = vector_to_string( curr->expr->value, ESUPPL_STATIC_BASE( curr->expr->suppl ), FALSE );
+        tmp = str = vector_to_string( curr->expr->value, ESUPPL_STATIC_BASE( curr->expr->suppl ), FALSE, 0 );
         slen = strlen( tmp );
         Try {
           if( (in_state = fsm_arg_parse_state( &str, funit->name )) == NULL ) {
@@ -642,7 +642,7 @@ void fsm_arg_parse_attr(
     } else if( (index == 2) && (strcmp( curr->name, "os" ) == 0) && (curr->expr != NULL) ) {
       if( fsml == NULL ) {
         int slen;
-        tmp = str = vector_to_string( curr->expr->value, ESUPPL_STATIC_BASE( curr->expr->suppl ), FALSE );
+        tmp = str = vector_to_string( curr->expr->value, ESUPPL_STATIC_BASE( curr->expr->suppl ), FALSE, 0 );
         slen = strlen( tmp );
         Try {
           if( (out_state = fsm_arg_parse_state( &str, funit->name )) == NULL ) {
@@ -670,7 +670,7 @@ void fsm_arg_parse_attr(
                (in_state != NULL) && (curr->expr != NULL) ) {
       if( fsml == NULL ) {
         int slen;
-        tmp = str = vector_to_string( curr->expr->value, ESUPPL_STATIC_BASE( curr->expr->suppl ), FALSE );
+        tmp = str = vector_to_string( curr->expr->value, ESUPPL_STATIC_BASE( curr->expr->suppl ), FALSE, 0 );
         slen = strlen( tmp );
         Try {
           if( (out_state = fsm_arg_parse_state( &str, funit->name )) == NULL ) {
@@ -694,7 +694,7 @@ void fsm_arg_parse_attr(
         print_output( user_msg, FATAL, __FILE__, __LINE__ );
         Throw 0;
       }
-    } else if( (index > 1) && (strcmp( curr->name, "trans" ) == 0) && (curr->expr != NULL) ) {
+    } else if( (index > 1) && (strncmp( curr->name, "trans", 5 ) == 0) && (curr->expr != NULL) ) {
       if( fsml == NULL ) {
         unsigned int rv = snprintf( user_msg, USER_MSG_LENGTH, "Attribute FSM name (%s) has not been previously created, file: %s",
                                     obf_sig( curr->name ), obf_file( funit->filename ) );
@@ -706,7 +706,7 @@ void fsm_arg_parse_attr(
       }
     } else {
       unsigned int rv;
-      tmp = vector_to_string( curr->expr->value, ESUPPL_STATIC_BASE( curr->expr->suppl ), FALSE );
+      tmp = vector_to_string( curr->expr->value, ESUPPL_STATIC_BASE( curr->expr->suppl ), FALSE, 0 );
       rv = snprintf( user_msg, USER_MSG_LENGTH, "Invalid covered_fsm attribute parameter (%s=%s), file: %s",
                      curr->name, tmp, obf_file( funit->filename ) );
       assert( rv < USER_MSG_LENGTH );
