@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2006-2009 Trevor Williams
+ Copyright (c) 2006-2010 Trevor Williams
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by the Free Software
@@ -463,9 +463,8 @@ expression* instance_find_expression_by_exclusion_id(
     
   if( root != NULL ) {
 
-    assert( root->funit != NULL );
- 
-    if( (root->funit->exp_head != NULL) && 
+    if( (root->funit != NULL) &&
+        (root->funit->exp_head != NULL) && 
         (root->funit->exp_head->exp->id <= id) && 
         (root->funit->exp_tail->exp->id >= id) ) {
 
@@ -512,11 +511,11 @@ int instance_find_fsm_arc_index_by_exclusion_id(
 
     fsm_link* fsml;
 
-    assert( root->funit != NULL );
-  
-    fsml = root->funit->fsm_head;
-    while( (fsml != NULL) && ((arc_index = arc_find_arc_by_exclusion_id( fsml->table->table, id )) == -1) ) {
-      fsml = fsml->next;
+    if( root->funit != NULL ) {
+      fsml = root->funit->fsm_head;
+      while( (fsml != NULL) && ((arc_index = arc_find_arc_by_exclusion_id( fsml->table->table, id )) == -1) ) {
+        fsml = fsml->next;
+      }
     }
 
     if( arc_index != -1 ) {
