@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2006-2009 Trevor Williams
+ Copyright (c) 2006-2010 Trevor Williams
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by the Free Software
@@ -264,7 +264,7 @@ static char* ovl_get_coverage_point(
   assert( stmt->exp->left->right->op == EXP_OP_STATIC );
   assert( ESUPPL_STATIC_BASE( stmt->exp->left->right->suppl ) == QSTRING );
 
-  cpoint = vector_to_string( stmt->exp->left->right->value, ESUPPL_STATIC_BASE( stmt->exp->left->right->suppl ), FALSE );
+  cpoint = vector_to_string( stmt->exp->left->right->value, ESUPPL_STATIC_BASE( stmt->exp->left->right->suppl ), FALSE, 0 );
 
   PROFILE_END;
 
