@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2006-2009 Trevor Williams
+ Copyright (c) 2006-2010 Trevor Williams
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by the Free Software
@@ -38,7 +38,8 @@ extern char           user_msg[USER_MSG_LENGTH];
 extern const exp_info exp_op_info[EXP_OP_NUM];
 extern db**           db_list;
 extern uint64         num_timesteps;
-extern bool           output_suppressed;
+extern bool           quiet_mode;
+extern bool           terse_mode;
 extern bool           debug_mode;
 extern int64          largest_malloc_size;
 extern bool           report_line;
@@ -1149,7 +1150,7 @@ static void rank_selected_cdd_cov(
   comp_cdd_cov*       tmp;
 
   /* Output status indicator, if necessary */
-  if( (!output_suppressed || debug_mode) && !rank_verbose ) {
+  if( ((!quiet_mode && !terse_mode) || debug_mode) && !rank_verbose ) {
     while( ((unsigned int)(((next_cdd + 1) / (float)comp_cdd_num) * 100) - (dots_output * 10)) >= 10 ) { 
       unsigned int rv;
       printf( "." );
@@ -1187,7 +1188,7 @@ static void rank_selected_cdd_cov(
     }
   }
 
-  if( (!output_suppressed || debug_mode) && !rank_verbose ) {
+  if( ((!quiet_mode && !terse_mode) || debug_mode) && !rank_verbose ) {
     if( (next_cdd + 1) == comp_cdd_num ) {
       unsigned int rv;
       if( dots_output < 10 ) {
@@ -1365,7 +1366,7 @@ static void rank_perform(
   timer*       atimer       = NULL;
   unsigned int rv;
 
-  if( (!output_suppressed || debug_mode) && !rank_verbose ) {
+  if( ((!quiet_mode && !terse_mode) || debug_mode) && !rank_verbose ) {
     printf( "Ranking CDD files " );
     rv = fflush( stdout );
     assert( rv == 0 );
@@ -1382,10 +1383,10 @@ static void rank_perform(
   unranked_merged = (uint16*)malloc_safe_nolimit( sizeof( uint16 ) * total );
 
   if( rank_verbose ) {
-    /*@-duplicatequals -formattype@*/
+    /*@-duplicatequals -formatcode -formattype@*/
     rv = snprintf( user_msg, USER_MSG_LENGTH, "\nRanking %u CDD files with %" FMT64 "u coverage points (%" FMT64 "u line, %" FMT64 "u toggle, %" FMT64 "u memory, %" FMT64 "u logic, %" FMT64 "u FSM, %" FMT64 "u assertion)",
               comp_cdd_num, total, num_cps[CP_TYPE_LINE], num_cps[CP_TYPE_TOGGLE], num_cps[CP_TYPE_MEM], num_cps[CP_TYPE_LOGIC], num_cps[CP_TYPE_FSM], num_cps[CP_TYPE_ASSERT] );
-    /*@=duplicatequals =formattype@*/
+    /*@=duplicatequals =formatcode =formattype@*/
     assert( rv < USER_MSG_LENGTH );
     print_output( user_msg, NORMAL, __FILE__, __LINE__ );
   }
@@ -1413,9 +1414,9 @@ static void rank_perform(
 
   if( rank_verbose ) {
     total_hitable = rank_count_cps( unranked_merged, total ); 
-    /*@-duplicatequals +ignorequals@*/
+    /*@-duplicatequals -formatcode +ignorequals@*/
     rv = snprintf( user_msg, USER_MSG_LENGTH, "Ignoring %" FMT64 "u coverage points that were not hit by any CDD file", (total - total_hitable) );
-    /*@=duplicatequals =ignorequals@*/
+    /*@=duplicatequals =formatcode =ignorequals@*/
     assert( rv < USER_MSG_LENGTH );
     print_output( user_msg, NORMAL, __FILE__, __LINE__ );
 
@@ -1440,9 +1441,9 @@ static void rank_perform(
     rv = snprintf( user_msg, USER_MSG_LENGTH, "  Ranked %u CDD files (Total ranked: %u, Remaining: %u)", next_cdd, next_cdd, (comp_cdd_num - next_cdd) );
     assert( rv < USER_MSG_LENGTH );
     print_output( user_msg, NORMAL, __FILE__, __LINE__ );
-    /*@-duplicatequals -formattype@*/
+    /*@-duplicatequals -formatcode -formattype@*/
     rv = snprintf( user_msg, USER_MSG_LENGTH, "  %" FMT64 "u points covered, %" FMT64 "u points remaining", ranked_cps, (total_hitable - ranked_cps) );
-    /*@=duplicatequals =formattype@*/
+    /*@=duplicatequals =formatcode =formattype@*/
     assert( rv < USER_MSG_LENGTH );
     print_output( user_msg, NORMAL, __FILE__, __LINE__ );
     rv = snprintf( user_msg, USER_MSG_LENGTH, "Completed phase 1 in %s", timer_to_string( atimer ) );
@@ -1477,9 +1478,9 @@ static void rank_perform(
     rv = snprintf( user_msg, USER_MSG_LENGTH, "  Ranked %u CDD files (Total ranked: %u, Remaining: %u)", (next_cdd - count), next_cdd, (comp_cdd_num - next_cdd) );
     assert( rv < USER_MSG_LENGTH );
     print_output( user_msg, NORMAL, __FILE__, __LINE__ );
-    /*@-duplicatequals -formattype@*/
+    /*@-duplicatequals -formatcode -formattype@*/
     rv = snprintf( user_msg, USER_MSG_LENGTH, "  %" FMT64 "u points covered, %" FMT64 "u points remaining", ranked_cps, (total_hitable - ranked_cps) );
-    /*@=duplicatequals =formattype@*/
+    /*@=duplicatequals =formatcode =formattype@*/
     assert( rv < USER_MSG_LENGTH );
     print_output( user_msg, NORMAL, __FILE__, __LINE__ );
     rv = snprintf( user_msg, USER_MSG_LENGTH, "Completed phase 2 in %s", timer_to_string( atimer ) );
@@ -1505,9 +1506,9 @@ static void rank_perform(
     rv = snprintf( user_msg, USER_MSG_LENGTH, "  Ranked %u CDD files (Total ranked: %u, Eliminated: %u)", cdds_ranked, (count + cdds_ranked), (comp_cdd_num - (count + cdds_ranked)) );
     assert( rv < USER_MSG_LENGTH );
     print_output( user_msg, NORMAL, __FILE__, __LINE__ );
-    /*@-duplicatequals -formattype@*/
+    /*@-duplicatequals -formatcode -formattype@*/
     rv = snprintf( user_msg, USER_MSG_LENGTH, "  %" FMT64 "u points covered, %" FMT64 "u points remaining", ranked_cps, (total_hitable - ranked_cps) );
-    /*@=duplicatequals =formattype@*/
+    /*@=duplicatequals =formatcode =formattype@*/
     assert( rv < USER_MSG_LENGTH );
     print_output( user_msg, NORMAL, __FILE__, __LINE__ );
     rv = snprintf( user_msg, USER_MSG_LENGTH, "Completed phase 3 in %s", timer_to_string( atimer ) );
@@ -1636,11 +1637,11 @@ static void rank_output(
         }
 
         /* Figure out the largest number for the first column */
-        /*@-duplicatequals -formattype@*/
+        /*@-duplicatequals -formatcode -formattype@*/
         rv = snprintf( str, 30, "%" FMT64 "u", total_timesteps );   col1 = strlen( str );
         assert( rv < 30 );
         rv = snprintf( str, 30, "%" FMT64 "u", ranked_timesteps );  col2 = strlen( str );
-        /*@=duplicatequals =formattype@*/
+        /*@=duplicatequals =formatcode =formattype@*/
         assert( rv < 30 );
 
         /* Create line for CDD files */
@@ -1734,7 +1735,7 @@ void command_rank(
   /* Output header information */
   rv = snprintf( user_msg, USER_MSG_LENGTH, COVERED_HEADER );
   assert( rv < USER_MSG_LENGTH );
-  print_output( user_msg, NORMAL, __FILE__, __LINE__ );
+  print_output( user_msg, HEADER, __FILE__, __LINE__ );
 
   Try {
 
@@ -1788,10 +1789,10 @@ void command_rank(
       /* Output the results */
       rank_output( comp_cdds, comp_cdd_num );
 
-      /*@-duplicatequals -formattype@*/
+      /*@-duplicatequals -formatcode -formattype@*/
       rv = snprintf( user_msg, USER_MSG_LENGTH, "Dynamic memory allocated:   %" FMT64 "u bytes", largest_malloc_size );
       assert( rv < USER_MSG_LENGTH );
-      /*@=duplicatequals =formattype@*/
+      /*@=duplicatequals =formatcode =formattype@*/
       print_output( "", NORMAL, __FILE__, __LINE__ );
       print_output( user_msg, NORMAL, __FILE__, __LINE__ );
       print_output( "", NORMAL, __FILE__, __LINE__ );
