@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2006-2009 Trevor Williams
+ Copyright (c) 2006-2010 Trevor Williams
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by the Free Software
@@ -131,7 +131,7 @@ bool report_exclusions = FALSE;
  If set to a boolean value of TRUE, displays GUI report viewer instead of generating text
  report files.
 */
-bool report_gui = FALSE;
+static bool report_gui = FALSE;
 
 /*!
  If set to a boolean value of TRUE, displays all vector combinational logic on a bitwise
@@ -185,7 +185,7 @@ bool flag_output_exclusion_ids = FALSE;
 /*!
  TCL interpreter for this application.
 */
-Tcl_Interp* interp;
+Tcl_Interp* interp = NULL;
 #endif
 
 /*!
@@ -195,7 +195,7 @@ static void report_usage() {
 
   printf( "\n" );
 #ifdef HAVE_TCLTK
-  printf( "Usage:  covered report (-h | -view | [<options>] <database_file>)\n" );
+  printf( "Usage:  covered report (-h | -view [<database_file>] | [<options>] <database_file>)\n" );
   printf( "\n" );
   printf( "   -view                        Uses the graphical report viewer for viewing reports.  If this\n" );
   printf( "                                 option is not specified, the text report will be generated.\n" );
@@ -325,10 +325,10 @@ bool report_parse_args(
     } else if( strncmp( "-view", argv[i], 5 ) == 0 ) {
 
 #ifdef HAVE_TCLTK
-      report_gui          = TRUE;
-      report_comb_depth   = REPORT_VERBOSE;
-      report_assertion    = TRUE;
-      report_memory       = TRUE;
+      report_gui        = TRUE;
+      report_comb_depth = REPORT_VERBOSE;
+      report_assertion  = TRUE;
+      report_memory     = TRUE;
 #else
       print_output( "The -view option is not available with this build", FATAL, __FILE__, __LINE__ );
       Throw 0;
@@ -1095,7 +1095,7 @@ void command_report(
   /* Output header information */
   rv = snprintf( user_msg, USER_MSG_LENGTH, COVERED_HEADER );
   assert( rv < USER_MSG_LENGTH );
-  print_output( user_msg, NORMAL, __FILE__, __LINE__ );
+  print_output( user_msg, HEADER, __FILE__, __LINE__ );
 
   Try {
 
@@ -1158,10 +1158,6 @@ void command_report(
 
           unsigned int rv;
 
-          if( input_db != NULL ) {
-            report_read_cdd_and_ready( input_db );
-          }
-
           /* Initialize the Tcl/Tk interpreter */
           interp = Tcl_CreateInterp();
           assert( interp );
@@ -1198,7 +1194,7 @@ void command_report(
           user_home       = getenv( "HOME" );
 
           /* Initialize TCL */
-          tcl_func_initialize( interp, argv[0], user_home, covered_home, covered_version, covered_browser );
+          tcl_func_initialize( interp, argv[0], user_home, covered_home, covered_version, covered_browser, input_db );
 
           /* Call the top-level Tcl file */
           slen      = strlen( covered_home ) + 30;
