@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2006-2009 Trevor Williams
+ Copyright (c) 2006-2010 Trevor Williams
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by the Free Software
@@ -493,7 +493,7 @@ void score_parse_define( const char* def ) { PROFILE(SCORE_PARSE_DEFINE);
     ptr++;
     define_macro( tmp, ptr );
   } else {
-    define_macro( tmp, "1" );
+    define_macro( tmp, "" );
   }
 
   /* Deallocate memory */
@@ -1129,7 +1129,7 @@ void command_score(
   /* Output header information */
   rv = snprintf( user_msg, USER_MSG_LENGTH, COVERED_HEADER );
   assert( rv < USER_MSG_LENGTH );
-  print_output( user_msg, NORMAL, __FILE__, __LINE__ );
+  print_output( user_msg, HEADER, __FILE__, __LINE__ );
 
   Try {
 
@@ -1177,10 +1177,10 @@ void command_score(
       if( dump_mode != DUMP_FMT_NONE ) {
         print_output( "***  Scoring completed successfully!  ***\n", NORMAL, __FILE__, __LINE__ );
       }
-      /*@-duplicatequals -formattype@*/
+      /*@-duplicatequals -formatcode -formattype@*/
       rv = snprintf( user_msg, USER_MSG_LENGTH, "Dynamic memory allocated:   %" FMT64 "u bytes", largest_malloc_size );
       assert( rv < USER_MSG_LENGTH );
-      /*@=duplicatequals =formattype@*/
+      /*@=duplicatequals =formatcode =formattype@*/
       print_output( user_msg, NORMAL, __FILE__, __LINE__ );
       print_output( "", NORMAL, __FILE__, __LINE__ );
 
